Documentation
¶
Overview ¶
Package benchmark contains benchmarking bound functions for internal use.
Index ¶
Constants ¶
const ( ShortString = "Hello, World!" LongString = "" /* 1610-byte string literal not displayed */ ShortStringUnicode = "Hello, 世界!" LongStringUnicode = "" /* 1730-byte string literal not displayed */ )
Variables ¶
var ( ShortSlice = make([]byte, 10) LongSlice = make([]byte, 100000) )
Functions ¶
func RunBenchmarks ¶
func RunBenchmarks(b Benchmarks)
func StringRetLong ¶
func StringRetLong() string
func StringRetShort ¶
func StringRetShort() string
Types ¶
type Benchmarks ¶
type Benchmarks interface {
// Run runs a named benchmark from a different thread, with
// no native call prior in the stack.
Run(name string, n int)
// RunDirect runs a named benchmark directly, with the native
// context from the call itself.
RunDirect(name string, n int)
// Callbacks for Go benchmarks
NewI() I
Noargs()
Onearg(_ int)
Oneret() int
Ref(_ I)
Manyargs(_, _, _, _, _, _, _, _, _, _ int)
String(_ string)
StringRetShort() string
StringRetLong() string
Slice(_ []byte)
}
Click to show internal directories.
Click to hide internal directories.